@@ -1,7 +1,9 @@
 from dataclasses import dataclass
-from typing import List
+from typing import List, Callable
 
 import pika
+from pika.adapters.blocking_connection import BlockingChannel
+from pika.spec import Basic, BasicProperties
 
 
 @dataclass
@@ -18,7 +20,7 @@ class RabbitOption:
 
 
 class RabbitMQ_Client:
-    def __init__(self, option: RabbitOption, callback):
+    def __init__(self, option: RabbitOption, callback: Callable[[BlockingChannel,Basic.Deliver, BasicProperties, bytes], None]):
         self.__rmq_url_connection_str = option.AmpqUrl
         self.__params = pika.URLParameters(self.__rmq_url_connection_str)
         self.__connection = pika.BlockingConnection(self.__params)
