@@ -12,7 +12,10 @@ class Indicator:
 
 @dataclass
 class SuperTrend(Indicator):
-    def __init__(self, Value_1: float, Value_2: float):
+    Value_1: float
+    Value_2: float
+
+    def __init__(self, Value_1: float = 0, Value_2: float = 0):
         super().__init__(Id="STD;Supertrend",
                          Name="SuperTrend",
                          Script="Script@tv-scripting-101!",
@@ -24,7 +27,10 @@ class SuperTrend(Indicator):
 
 @dataclass
 class Volume(Indicator):
-    def __init__(self, Value_1: float, Value_2: float):
+    Value_1: float
+    Value_2: float
+
+    def __init__(self, Value_1: float = 0, Value_2: float = 0):
         super().__init__(Id="",
                          Name="Volume",
                          Script="Volume",
@@ -36,7 +42,11 @@ class Volume(Indicator):
 
 @dataclass
 class TripleMovingAverages(Indicator):
-    def __init__(self, Value_1: float, Value_2: float, Value_3: float):
+    Value_1: float
+    Value_2: float
+    Value_3: float
+
+    def __init__(self, Value_1: float = 0, Value_2: float = 0, Value_3: float = 0):
         super().__init__(Id="PUB;y784PkOKflCjfhCiCB4ewuC0slMtB8PQ",
                          Name="TripleMovingAverages",
                          Script="Script@tv-scripting-101!",
